
Name:           prelude-manager
Version:        5.2.0
Release:    1%{?dist}
Summary:        Bus communicator for Prelude modules and other IDMEF agents
License:        GPLv2+
URL:            https://www.prelude-siem.org/
Source0:        https://www.prelude-siem.org/pkg/src/%{version}/%{name}-%{version}.tar.gz
Source1:        %{name}.service
Source2:        %{name}-tmpfiles.conf
Patch0:         prelude-manager-5.2.0-gnutls_priority_init.patch
Patch1:         prelude-manager-5.2.0-fix_etc_perms.patch
Patch2:         prelude-manager-5.2.0-fix_cond_test.patch
Patch3:         prelude-manager-5.2.0-fix-test_rwlock1.patch
Patch4:         prelude-manager-5.2.0-fix_thread_create.patch
Patch5:         prelude-manager-5.2.0-Add_missing_gnutls_deps.patch
Patch6:         prelude-manager-5.2.0-fix-test-perror2.patch
BuildRequires: make
BuildRequires:  gcc
BuildRequires:  systemd
BuildRequires:  libgcrypt-devel
BuildRequires:  libgpg-error-devel
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(libprelude) >= %{version}
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  libpreludedb-devel >= %{version}
BuildRequires:  net-snmp-devel

%{?systemd_requires}
Requires:       prelude-tools

%ifnarch s390
BuildRequires:  valgrind
%endif

Provides:       bundled(gnulib) = 20180903

%description
Prelude Manager is the main program of the Prelude SIEM suite. It is a
multithreaded server which handles connections from the Prelude modules. It is
able to register local or remote agents, let the operator configure them
remotely, receive alerts, and store alerts in a database or any format supported
by reporting plugins, thus providing centralized logging and analysis. The IDMEF
standard is used for alert representation. Support for filtering plugins allows
you to hook in different places in the Manager to define custom criteria for
alert logging.

%package        db-plugin
Summary:        Database report plugin for Prelude Manager
Requires:       %{name} = %{version}-%{release}
Suggests:       preludedb-mysql
Suggests:       preludedb-pgsql
Suggests:       preludedb-sqlite3

%description db-plugin
This plugin allows prelude-manager to write to database.

%package        xml-plugin
Summary:        XML report plugin for Prelude Manager
Requires:       %{name} = %{version}-%{release}

%description xml-plugin
This plugin allows prelude-manager to log into XML files.

%package        relaying-plugin
Summary:        Relaying plugin for Prelude Manager
Requires:       %{name} = %{version}-%{release}

%description relaying-plugin
This plugin allows prelude-manager relay IDMEF alerts to another
prelude-manager.

%package        script-plugin
Summary:        Script plugin for Prelude Manager
Requires:       %{name} = %{version}-%{release}

%description script-plugin
This plugin allows prelude-manager to execute scripts.

%package        snmp-plugin
Summary:        SNMP plugin for Prelude Manager
Requires:       %{name} = %{version}-%{release}
Requires:       net-snmp-libs

%description snmp-plugin
This plugin allows prelude-manager to report alerts through SNMP.

%package        devel
Summary:        Libraries, includes, etc. to develop Prelude Manager plugins
Requires:       %{name}-db-plugin = %{version}-%{release}
Requires:       %{name}-xml-plugin = %{version}-%{release}
Requires:       %{name}-relaying-plugin = %{version}-%{release}
Requires:       %{name}-script-plugin = %{version}-%{release}
Requires:       %{name}-snmp-plugin = %{version}-%{release}
Requires:       %{name} = %{version}-%{release}

%description devel
Devel headers for Prelude Manager.

%package doc
Summary:        Documentation for prelude-manager
BuildArch:      noarch

%description doc
Provides documentation for prelude-manager.

%prep
%autosetup -p1

%build
%define _lto_cflags %{nil}

%configure \
    --disable-static \
    --enable-shared
%make_build

%install
%make_install

find %{buildroot} -name '*.la' -delete

mkdir -p %{buildroot}%{_localstatedir}/lib/%{name}
mkdir -p %{buildroot}%{_sysconfdir}/prelude/profile/%{name}
mkdir -p %{buildroot}%{_var}/spool/%{name}/scheduler

mkdir -p %{buildroot}%{_sbindir}
mv %{buildroot}%{_bindir}/%{name} %{buildroot}%{_sbindir}/%{name}

rm -rf src/.libs

install -D -p -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service

mkdir -p %{buildroot}%{_tmpfilesdir}
install -m 0644 %{SOURCE2} %{buildroot}%{_tmpfilesdir}/%{name}.conf
mkdir -p %{buildroot}/run
install -d -m 0755 %{buildroot}/run/%{name}/

%check
make check

%post
%systemd_post %{name}.service

%preun
%systemd_preun %{name}.service

%postun
%systemd_postun_with_restart %{name}.service 

%files
%license COPYING HACKING.README
%doc README
%{_unitdir}/%{name}.service
%{_sbindir}/%{name}
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/decodes
%dir %{_libdir}/%{name}/filters
%dir %{_libdir}/%{name}/reports
%{_libdir}/%{name}/filters/idmef-criteria.so
%{_libdir}/%{name}/filters/thresholding.so
%{_libdir}/%{name}/reports/debug.so
%{_libdir}/%{name}/reports/smtp.so
%{_libdir}/%{name}/reports/textmod.so
%{_libdir}/%{name}/decodes/normalize.so
%dir %{_var}/spool/%{name}
%dir %{_var}/spool/%{name}/scheduler
%dir /run/%{name}/
%{_tmpfilesdir}/%{name}.conf
%{_localstatedir}/lib/%{name}
%{_sysconfdir}/prelude/profile/%{name}
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/*.conf
%{_mandir}/man1/%{name}.1*

%files db-plugin
%{_libdir}/%{name}/reports/db.so

%files xml-plugin
%{_libdir}/%{name}/reports/xmlmod.so
%dir %{_datadir}/%{name}/
%dir %{_datadir}/%{name}/xmlmod
%{_datadir}/%{name}/xmlmod/idmef-message.dtd

%files relaying-plugin
%{_libdir}/%{name}/reports/relaying.so

%files script-plugin
%{_libdir}/%{name}/reports/script.so

%files snmp-plugin
%{_libdir}/%{name}/reports/snmp.so

%files devel
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*.h

%files doc
%license COPYING HACKING.README
%doc AUTHORS COPYING ChangeLog HACKING.README NEWS README
%doc %{_docdir}/%{name}/smtp/template.example
%doc %{_docdir}/%{name}/snmp/PRELUDE-SIEM-MIB.mib

%changelog
* Mon Jul 01 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.2.0-1
- initial build
